@@ -22,9 +22,10 @@ from pulpcore.plugin.viewsets import (
     BaseFilterSet,
     ContentFilter,
     ContentViewSet,
+    HyperlinkRelatedFilter,
     NamedModelViewSet,
+    NoArtifactContentUploadViewSet,
     OperationPostponedResponse,
-    ReadOnlyContentViewSet,
     RemoteViewSet,
     RepositoryViewSet,
     RepositoryVersionViewSet,
@@ -218,6 +219,15 @@ class SignatureFilter(ContentFilter):
     A filter for signatures.
     """
 
+    signed_collection = HyperlinkRelatedFilter(
+        field_name="signed_collection",
+        help_text=_("Filter signatures for collection version"),
+    )
+    signing_service = HyperlinkRelatedFilter(
+        field_name="signing_service",
+        help_text=_("Filter signatures produced by signature service"),
+    )
+
     class Meta:
         model = CollectionVersionSignature
         fields = {
@@ -227,7 +237,7 @@ class SignatureFilter(ContentFilter):
         }
 
 
-class CollectionVersionSignatureViewSet(ReadOnlyContentViewSet):
+class CollectionVersionSignatureViewSet(NoArtifactContentUploadViewSet):
     """
     ViewSet for looking at signature objects for CollectionVersion content.
     """
